from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pdcch:
	"""Pdcch commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pdcch", core, parent)

	@property
	def psymbols(self):
		"""psymbols commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_psymbols'):
			from .Pdcch_.Psymbols import Psymbols
			self._psymbols = Psymbols(self._core, self._base)
		return self._psymbols

	@property
	def alevel(self):
		"""alevel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alevel'):
			from .Pdcch_.Alevel import Alevel
			self._alevel = Alevel(self._core, self._base)
		return self._alevel

	def clone(self) -> 'Pdcch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pdcch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
